HttpReply

Struct HttpReply 

pub struct HttpReply<'a> {
Show 18 fields pub af: AddressFamily, pub bsize: Option<u64>, pub dst_addr: Cow<'a, str>, pub err: Option<Cow<'a, str>>, pub header: Option<Vec<Cow<'a, str>>>, pub hsize: Option<u64>, pub method: Method, pub readtiming: Option<Vec<ReadTiming>>, pub res: Option<u32>, pub rt: Option<f64>, pub src_addr: Option<Cow<'a, str>>, pub subid: Option<i64>, pub submax: Option<i64>, pub time: Option<UnixTimestamp>, pub ttc: Option<f64>, pub ttfb: Option<f64>, pub ttr: Option<f64>, pub ver: Option<Cow<'a, str>>,
}

Fields

af: AddressFamily

address family, 4 or 6 (integer)

bsize: Option<u64>

size of body in octets (int)

dst_addr: Cow<'a, str>

target address (string)

err: Option<Cow<'a, str>>

[optional] other failure (string)

header: Option<Vec<Cow<'a, str>>>

[optional] elements are strings. The last string can be empty to indicate the end of enders or end with “[…]” to indicate truncation (array of strings)

hsize: Option<u64>

header size in octets (int)

method: Method

“GET”, “HEAD”, or “POST” (string)

readtiming: Option<Vec<ReadTiming>>

[optional] timing results for reply data (array of objects)

res: Option<u32>

HTTP result code (int)

rt: Option<f64>

time to execute request excluding DNS (float)

src_addr: Option<Cow<'a, str>>

source address used by probe (string)

subid: Option<i64>

[optional] sequence number of this result within a group of results, when the ‘all’ option is used without the ‘combine’ option (int)

submax: Option<i64>

[optional] total number of results within a group (int)

time: Option<UnixTimestamp>

[optional] Unix timestamp, when the ‘all’ option is used with the ‘combine’ option (int)

ttc: Option<f64>

[optional] time to connect to the target (in milli seconds) (float)

ttfb: Option<f64>

[optional] time to first response byte received by measurent code after starting to connect (in milli seconds) (float)

ttr: Option<f64>

[optional] time to resolve the DNS name (in milli seconds) (float)

ver: Option<Cow<'a, str>>

major, minor version of http server (string)